Name:       dbus-java
Version:    2.7
Release:    3%{?dist}
Summary:    Java implementation of the DBus protocol
Group:      Development/Libraries
License:    AFL or LGPLv2
URL:        http://freedesktop.org/wiki/Software/DBusBindings
#URL2:      http://dbus.freedesktop.org/doc/dbus-java/
Source:     http://dbus.freedesktop.org/releases/%{name}/%{name}-%{version}.tar.gz
Patch1:     classpath_fix.patch
# fedora specific paths
Patch2:     parallel.patch

BuildRoot:  %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  java-1.6.0-openjdk-devel
BuildRequires:  jpackage-utils
BuildRequires:  texlive-latex
BuildRequires:  tetex-tex4ht
BuildRequires:  docbook-utils
BuildRequires:  gettext
BuildRequires:  libmatthew-java
BuildRequires:  docbook2X

Requires:   java-1.6.0-openjdk
Requires:   jpackage-utils
Requires:   libmatthew-java

BuildArch:      noarch

%description
D-Bus is a message bus system, a simple way for applications to
talk to one another. In addition to interprocess communication,
D-Bus helps coordinate process lifecycle; it makes it simple and
reliable to code a "single instance" application or daemon, and to
launch applications and daemons on demand when their services are
needed.

This is a complete independent implementation of the D-Bus protocol
in Java. It comprises a library to write programs in Java which
access D-Bus, a tool for generating stubs from D-Bus introspection
data and a simple daemon. Being written in Java it works on both
Windows and Linux (and other Unix-like systems).

When using a TCP transport it is entirely Java-based; when using
Unix-sockets it requires a small JNI library to use Unix-Sockets.


%package javadoc
Summary:    Javadocs for %{name}
Group:      Development/Libraries
Requires:   jpackage-utils


%description javadoc
Javadocs for %{name}


%prep
%setup -q
%patch1 -p1
%patch2 -p1

sed -i "s|!doctype|!DOCTYPE|g" *.sgml
sed -i 's|<!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN"|<!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN" "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd"|g' *.sgml

%build
# no configure file
make %{?_smp_mflags} \
    DOCBOOKTOMAN="db2x_docbook2man --to-stdout"\
    -j1 \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_libdir}/libmatthew-java


%check
make check \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_libdir}/libmatthew-java


%install
rm -rf $RPM_BUILD_ROOT
make install \
    DESTDIR=$RPM_BUILD_ROOT \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_libdir}/libmatthew-java

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%{_javadir}/%{name}
%{_bindir}/CreateInterface
%{_bindir}/DBusCall
%{_bindir}/DBusDaemon
%{_bindir}/DBusViewer
%{_bindir}/ListDBus
%doc %{_defaultdocdir}/%{name}
%doc %{_mandir}/man1/CreateInterface.1.gz
%doc %{_mandir}/man1/DBusCall.1.gz
%doc %{_mandir}/man1/DBusDaemon.1.gz
%doc %{_mandir}/man1/DBusViewer.1.gz
%doc %{_mandir}/man1/ListDBus.1.gz

%files javadoc
%defattr(-,root,root,-)
%{_javadocdir}/%{name}


%changelog
* Fri Jan 15 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-3
- Add docbook2X dependency.

* Fri Jan 15 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-2
- Fix manpages generation.

* Wed Jan 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-1
- Update to upstream 2.7.
- Drop gcj_support.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar 17 2009 Omair Majid <omajid@redhat.com> - 2.5.1-1
- update to 2.5.1
- Added patches from François Kooman <fkooman@tuxed.net>
- Added docs.patch (already upstream). Replaces docbook.patch and 
  man_fixes.patch
- Add missing TestSignalInterface2 interface (already upstream)

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jul 7 2008 Omair Majid <omajid@redhat.com> - 2.5-3
- Added a patch to fix the htlatex environment
- added -j1 to make to fix the race condition in makefile

* Mon Jun 30 2008 Omair Majid <omajid@redhat.com> - 2.5-2
- fixed incoherent name warning from rpmlint
- fixed wrapper script paths
- added check section

* Wed Jun 25 2008 Omair Majid <omajid@redhat.com> - 2.5-1
- Initial build
